DataLad extension template
**************************

This is a template for creating a `DataLad <http://datalad.org>`__ extension
that equips DataLad with additional functionality.


API
===

High-level API commands
-----------------------

.. currentmodule:: datalad.api
.. autosummary::
   :toctree: generated

   fsspec_cache_clear
   fsspec_head
   fusefs


Command line reference
----------------------

.. toctree::
   :maxdepth: 1

   generated/man/datalad-fsspec-cache-clear
   generated/man/datalad-fsspec-head
   generated/man/datalad-fusefs


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. |---| unicode:: U+02014 .. em dash
